# Copyright: (c) 2022 Jordan Borean (@jborean93) <jborean93@gmail.com>
# MIT License (see LICENSE or https://opensource.org/licenses/MIT)

from krb5._context import Context
from krb5._creds_opt import GetInitCredsOpt

def get_init_creds_opt_set_pac_request(
    context: Context,
    opt: GetInitCredsOpt,
    req_pac: bool,
) -> None:
    """Ask KDC to include or not include a PAC in the ticket.

    If this option is set, the AS request will include a PAC-REQUEST pa-data
    item explicitly asking the KDC to either include or include a privilege
    attribute certificate in the ticket authorization data. By default, no
    request is made; typically the KDC will default to including a PAC if it
    supports them.

    Args:
        context: Krb5 context.
        opt: The initial credential options.
        canonicalize: Whether to set or unset the canonicalize option.
    """



# Copyright: (c) 2024 Jordan Borean (@jborean93) <jborean93@gmail.com>
# MIT License (see LICENSE or https://opensource.org/licenses/MIT)

from __future__ import annotations

from krb5._context import Context
from krb5._creds import Creds

def marshal_credentials(
    context: Context,
    creds: Creds,
) -> bytes:
    """Serialize creds.

    Serialize credentials in the format used by the FILE ccache format
    (version 4) and KCM ccache protocol.

    This is only present when compiled against MIT 1.20 or newer.

    Args:
        context: Krb5 context.
        creds: Credentials to serialize.

    Returns:
        bytes: The serialized credentials.
    """

def unmarshal_credentials(
    context: Context,
    data: bytes,
) -> Creds:
    """Deserialize creds.

    Deserialize credentials from the format used by the FILE ccache format
    (version 4) and KCM ccache protocol.

    This is only present when compiled against MIT 1.20 or newer.

    Args:
        context: Krb5 context.
        data: serialized credentials.

    Returns:
        Creds: The unserialized credentials.
    """



# Copyright: (c) 2022 Jordan Borean (@jborean93) <jborean93@gmail.com>
# MIT License (see LICENSE or https://opensource.org/licenses/MIT)

from krb5._context import Context
from krb5._kt import KeyTab

def kt_have_content(
    context: Context,
    keytab: KeyTab,
) -> bool:
    """Check if a keytab exists and contains entries.

    Checks if the keytab passed in exists and contains entries.

    Args:
        context: Krb5 context.
        keytab: They keytab to query.

    Returns:
        bool: Whether the keytab exists and contains entries.
    """
